@@ -5,8 +5,14 @@
 #'
 #' @return A vector of breaks with frequency equal to the count of dates they
 #'   contain.
+#' @importFrom graphics hist
 #' @noRd
 group_dates <- function(dates, breaks) {
-  counts <- count_dates(dates, breaks)
+  histogram <- hist(
+    as.integer(dates),
+    breaks = c(as.integer(breaks), Inf), 
+    right = FALSE, 
+    plot = FALSE)
+  counts <- as.integer(histogram$counts)
   rep(breaks, counts)
-}
+}
\ No newline at end of file
